[![license](https://img.shields.io/badge/license-MIT-brightgreen)](https://spdx.org/licenses/MIT.html)
[![pipelines](https://gitlab.com/jlecomte/projects/python/torxtools/badges/master/pipeline.svg)](https://gitlab.com/jlecomte/projects/python/torxtools/pipelines)
[![coverage](https://gitlab.com/jlecomte/projects/python/torxtools/badges/master/coverage.svg)](https://jlecomte.gitlab.io/projects/torxtools/coverage/index.html)

# torxtools

Less generic functionalities than Phillips and Pozidriv tools. One size fits most. MacGyver's French army spork.

Quick and dirty library that holds functions used in projects with similarities.

## Installation from PyPI

You can install the latest version from PyPI package repository.

~~~bash
python3 -mpip install -U torxtools
~~~

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Locations

  * GitLab: [https://gitlab.com/jlecomte/projects/python/torxtools](https://gitlab.com/jlecomte/projects/python/torxtools)
  * PyPi: [https://pypi.org/project/torxtools](https://pypi.org/project/torxtools)
